## User Guide

- [Frequency Bands](frequency.md)
- [Hardware Guide](hardware.md)
- Receiver Configuration:
    - [Novra S400](s400.md)
    - [TBS5927](tbs.md)
    - [SDR Setup](sdr.md)
- [Bitcoin Satellite](bitcoin.md)
- [Antenna Pointing](antenna-pointing.md)
- [Satellite API](../api/README.md)
